function figsize(tile, szfrac, figs)
% Copyright (C) 2013 - Pieter V. Reyneke, South Africa
%
% Open Source licence, use whereever you like but at own risk, keep this
% complete copyright notice in the code and please send me updates and 
% report errors to pieter.reyneke@gmail.com. Will give recognition, if
% requested, after any valid comment leading to an update was recieved. 
%
% Author: PV Reyneke

if ( nargin < 1 )
    tile = 0;
end

if ( nargin < 2 )
    szfrac = [0.7,0.8];
end
    
    
if ( nargin < 3 )                      % If no input arguments...
   figs = findobj( 'Type', 'figure' );  % ...find all figures.
   figs  = sort( figs );
end

if isempty( figs )
   disp( 'No open figures or no figures specified.' );
   return;
end

nfigs = length( figs );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set miscellaneous parameter.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nfigs = length(figs);           % Number of figures.

if (tile)
    nh = ceil( sqrt(nfigs) );       % Number of figures horisontally.
    nv = ceil( nfigs/nh );          % Number of figures vertically.
else
    nh = 1;
    nv = 1;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Get the screen size.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

set( 0, 'Units', 'pixels' );            % Set root units.
scrdim = get( 0, 'ScreenSize' );        % Get screen size.
scrwid = scrdim(3);           % Screen width.
scrhgt = scrdim(4);           % Screen height.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The elements in the vector specifying the position.
% 1 - Window left position
% 2 - Window bottom position
% 3 - Window horizontal size
% 4 - Window vertical size
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

hspc   = 50;            % Horisontal space.
topspc = 80;            % Space above top figure.
medspc = 80;            % Space between figures.
botspc = 40;            % Space below bottom figure.

figwid = ( scrwid - (nh+1)*hspc )/nh;
fighgt = ( scrhgt - (topspc+botspc) - (nv-1)*medspc )/nv;
figwid = round(figwid)*szfrac(1);
fighgt = round(fighgt)*szfrac(2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Put the figures where they belong.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (tile)
    for row = 1:nv
       for col = 1:nh
          idx = (row-1)*nh + col;
          if ( idx <= nfigs )
             figlft = col*hspc + (col-1)*figwid;
             figbot = scrhgt - topspc - row*fighgt - (row-1)*medspc;
             figpos = [ figlft figbot figwid fighgt ];    % Figure position.
             fighnd = figs(idx);                          % Figure handle.
             units = get( fighnd, 'Units' );              % Get units.
             set( fighnd, 'Units', 'pixels' );            % Set new units.
             set( fighnd, 'Position', figpos );           % Set position.
             figure( fighnd );                            % Raise figure.
          end
       end
    end
else
    for (idx = 1:size(figs,1))
             col = 1;
             row = 1;
             figlft = col*hspc + (col-1)*figwid;
             figbot = scrhgt - topspc - row*fighgt - (row-1)*medspc;
             figpos = [ figlft figbot figwid fighgt ];    % Figure position.
             fighnd = figs(idx);                          % Figure handle.
             units = get( fighnd, 'Units' );              % Get units.
             set( fighnd, 'Units', 'pixels' );            % Set new units.
             set( fighnd, 'Position', figpos );           % Set position.
             figure( fighnd );                            % Raise figure.
    end    
end